summaryrefslogtreecommitdiff
path: root/zhm/zhm.c
diff options
context:
space:
mode:
authorGravatar John Kohl <jtkohl@mit.edu>1988-10-03 12:05:58 +0000
committerGravatar John Kohl <jtkohl@mit.edu>1988-10-03 12:05:58 +0000
commit4e018d5a2dfe481ac443ac862b6d74d60f2f7938 (patch)
treefc44693dab523020f8304ac33f3cab2deb546c9b /zhm/zhm.c
parent8a97239e1a15ddabef850d281c89a881dc28059f (diff)
use #define'ed names for zephyr-hm and zephyr-clt
Diffstat (limited to 'zhm/zhm.c')
-rw-r--r--zhm/zhm.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/zhm/zhm.c b/zhm/zhm.c
index 17b6032..fc65c61 100644
--- a/zhm/zhm.c
+++ b/zhm/zhm.c
@@ -295,8 +295,8 @@ void init_hm()
thanks to inetd */
} else {
/* Open client socket, for receiving client and server notices */
- if ((sp = getservbyname("zephyr-hm", "udp")) == NULL) {
- printf("No zephyr-hm entry in /etc/services.\n");
+ if ((sp = getservbyname(HM_SVCNAME, "udp")) == NULL) {
+ printf("No %s entry in /etc/services.\n", HM_SVCNAME);
exit(1);
}
cli_port = sp->s_port;
@@ -312,8 +312,8 @@ void init_hm()
/* Open the server socket */
- if ((sp = getservbyname("zephyr-clt", "udp")) == NULL) {
- printf("No zephyr-clt entry in /etc/services.\n");
+ if ((sp = getservbyname(SERVER_SVCNAME, "udp")) == NULL) {
+ printf("No %s entry in /etc/services.\n", SERVER_SVCNAME);
exit(1);
}
@@ -337,7 +337,7 @@ void init_hm()
serv_sin.sin_port = sp->s_port;
/* Set up communications with server */
/* target is "zephyr-clt" port on server machine */
serv_sin.sin_family = AF_INET;
@@ -337,7 +337,7 @@ void init_hm()
serv_sin.sin_port = sp->s_port;
/* Set up communications with server */
- /* target is "zephyr-clt" port on server machine */
+ /* target is SERVER_SVCNAME port on server machine */
serv_sin.sin_family = AF_INET;